@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -34,6 +34,7 @@
 #include "sh-quote.h"
 #include "pathname.h"
 #include "xalloc.h"
+#include "xallocsa.h"
 #include "error.h"
 #include "gettext.h"
 
@@ -98,7 +99,7 @@ execute_java_class (const char *class_name,
     {
       char *exe_pathname = concatenated_pathname (exe_dir, class_name, EXEEXT);
       char *old_classpath;
-      char **argv = (char **) alloca ((1 + nargs + 1) * sizeof (char *));
+      char **argv = (char **) xallocsa ((1 + nargs + 1) * sizeof (char *));
       unsigned int i;
 
       /* Set CLASSPATH.  */
@@ -122,6 +123,8 @@ execute_java_class (const char *class_name,
       /* Reset CLASSPATH.  */
       reset_classpath (old_classpath);
 
+      freesa (argv);
+
       goto done1;
     }
 
@@ -151,7 +154,7 @@ execute_java_class (const char *class_name,
 	  command_length += 1 + shell_quote_length (*arg);
 	command_length += 1;
 
-	command = (char *) alloca (command_length);
+	command = (char *) xallocsa (command_length);
 	p = command;
 	/* Don't shell_quote $JAVA, because it may consist of a command
 	   and options.  */
@@ -178,6 +181,8 @@ execute_java_class (const char *class_name,
 	argv[3] = NULL;
 	err = executer (java, "/bin/sh", argv, private_data);
 
+	freesa (command);
+
 	/* Reset CLASSPATH.  */
 	reset_classpath (old_classpath);
 
@@ -206,8 +211,8 @@ execute_java_class (const char *class_name,
 	argv[0] = "gij";
 	argv[1] = "--version";
 	argv[2] = NULL;
-	exitstatus = execute ("gij", "gij", argv, false, true, true, true,
-			      false);
+	exitstatus = execute ("gij", "gij", argv, false, false, true, true,
+			      true, false);
 	gij_present = (exitstatus == 0);
 	gij_tested = true;
       }
@@ -215,7 +220,7 @@ execute_java_class (const char *class_name,
     if (gij_present)
       {
 	char *old_classpath;
-	char **argv = (char **) alloca ((2 + nargs + 1) * sizeof (char *));
+	char **argv = (char **) xallocsa ((2 + nargs + 1) * sizeof (char *));
 	unsigned int i;
 
 	/* Set CLASSPATH.  */
@@ -240,6 +245,8 @@ execute_java_class (const char *class_name,
 	/* Reset CLASSPATH.  */
 	reset_classpath (old_classpath);
 
+	freesa (argv);
+
 	goto done2;
       }
   }
@@ -257,8 +264,8 @@ execute_java_class (const char *class_name,
 	argv[0] = "java";
 	argv[1] = "-version";
 	argv[2] = NULL;
-	exitstatus = execute ("java", "java", argv, false, true, true, true,
-			      false);
+	exitstatus = execute ("java", "java", argv, false, false, true, true,
+			      true, false);
 	java_present = (exitstatus == 0);
 	java_tested = true;
       }
@@ -266,7 +273,7 @@ execute_java_class (const char *class_name,
     if (java_present)
       {
 	char *old_classpath;
-	char **argv = (char **) alloca ((2 + nargs + 1) * sizeof (char *));
+	char **argv = (char **) xallocsa ((2 + nargs + 1) * sizeof (char *));
 	unsigned int i;
 
 	/* Set CLASSPATH.  We don't use the "-classpath ..." option because
@@ -293,6 +300,8 @@ execute_java_class (const char *class_name,
 	/* Reset CLASSPATH.  */
 	reset_classpath (old_classpath);
 
+	freesa (argv);
+
 	goto done2;
       }
   }
@@ -309,8 +318,8 @@ execute_java_class (const char *class_name,
 
 	argv[0] = "jre";
 	argv[1] = NULL;
-	exitstatus = execute ("jre", "jre", argv, false, true, true, true,
-			      false);
+	exitstatus = execute ("jre", "jre", argv, false, false, true, true,
+			      true, false);
 	jre_present = (exitstatus == 0 || exitstatus == 1);
 	jre_tested = true;
       }
@@ -318,7 +327,7 @@ execute_java_class (const char *class_name,
     if (jre_present)
       {
 	char *old_classpath;
-	char **argv = (char **) alloca ((2 + nargs + 1) * sizeof (char *));
+	char **argv = (char **) xallocsa ((2 + nargs + 1) * sizeof (char *));
 	unsigned int i;
 
 	/* Set CLASSPATH.  We don't use the "-classpath ..." option because
@@ -345,6 +354,8 @@ execute_java_class (const char *class_name,
 	/* Reset CLASSPATH.  */
 	reset_classpath (old_classpath);
 
+	freesa (argv);
+
 	goto done2;
       }
   }
@@ -364,8 +375,8 @@ execute_java_class (const char *class_name,
 	argv[0] = "jview";
 	argv[1] = "-?";
 	argv[2] = NULL;
-	exitstatus = execute ("jview", "jview", argv, false, true, true, true,
-			      false);
+	exitstatus = execute ("jview", "jview", argv, false, false, true, true,
+			      true, false);
 	jview_present = (exitstatus == 0 || exitstatus == 1);
 	jview_tested = true;
       }
@@ -373,7 +384,7 @@ execute_java_class (const char *class_name,
     if (jview_present)
       {
 	char *old_classpath;
-	char **argv = (char **) alloca ((2 + nargs + 1) * sizeof (char *));
+	char **argv = (char **) xallocsa ((2 + nargs + 1) * sizeof (char *));
 	unsigned int i;
 
 	/* Set CLASSPATH.  */
@@ -398,6 +409,8 @@ execute_java_class (const char *class_name,
 	/* Reset CLASSPATH.  */
 	reset_classpath (old_classpath);
 
+	freesa (argv);
+
 	goto done2;
       }
   }
