@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -355,7 +355,7 @@ conv_from_java (char *string)
 static char *
 read_escaped_string (bool in_key)
 {
-  static unsigned short *buffer; 
+  static unsigned short *buffer;
   static size_t bufmax;
   static size_t buflen;
   int c;
