@@ -1,5 +1,5 @@
 /* xgettext PO backend.
-   Copyright (C) 2001-2002 Free Software Foundation, Inc.
+   Copyright (C) 2001-2003 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2001.
 
    This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 
 #define EXTENSIONS_PO \
@@ -22,9 +22,10 @@
   { "pot",    "PO"    },						\
 
 #define SCANNERS_PO \
-  { "PO", extract_po, NULL },						\
+  { "PO",		extract_po, NULL, NULL, NULL },			\
 
 /* Scan a PO file and add its translatable strings to mdlp.  */
 extern void extract_po (FILE *fp, const char *real_filename,
 			const char *logical_filename,
+			flag_context_list_table_ty *flag_table,
 			msgdomain_list_ty *mdlp);
